Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(660)

Unified Diff: runtime/lib/date_patch.dart

Issue 11227055: Move DateImplementation from coreimpl to core, making it private. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 8 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « lib/coreimpl/date.dart ('k') | runtime/lib/lib_impl_sources.gypi » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/lib/date_patch.dart
diff --git a/runtime/lib/date_patch.dart b/runtime/lib/date_patch.dart
index aee640f525ef17a0f4f377bee1dd0f8dc220f486..8e2b8cc04c21303fa0b347ca55067776b197e2cd 100644
--- a/runtime/lib/date_patch.dart
+++ b/runtime/lib/date_patch.dart
@@ -3,16 +3,16 @@
// BSD-style license that can be found in the LICENSE file.
// Dart core library.
-// VM implementation of DateImplementation.
-patch class DateImplementation {
- /* patch */ DateImplementation(int year,
- int month,
- int day,
- int hour,
- int minute,
- int second,
- int millisecond,
- bool isUtc)
+// VM implementation of _DateImpl.
+patch class _DateImpl {
+ /* patch */ _DateImpl(int year,
+ int month,
+ int day,
+ int hour,
+ int minute,
+ int second,
+ int millisecond,
+ bool isUtc)
: this.isUtc = isUtc,
this.millisecondsSinceEpoch = _brokenDownDateToMillisecondsSinceEpoch(
year, month, day, hour, minute, second, millisecond, isUtc) {
@@ -20,7 +20,7 @@ patch class DateImplementation {
if (isUtc === null) throw new ArgumentError();
}
- /* patch */ DateImplementation.now()
+ /* patch */ _DateImpl.now()
: isUtc = false,
millisecondsSinceEpoch = _getCurrentMs() {
}
« no previous file with comments | « lib/coreimpl/date.dart ('k') | runtime/lib/lib_impl_sources.gypi » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698